<?php

namespace App\Classes\FTN\Process\Netmail\Robot\Areafix;

use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Log;

use App\Jobs\AreafixRescan;

// SCAN - Send unsent echomail
class Scan extends Base
{
	private const LOGKEY = 'AFS';
	private const command = '%SCAN';

	public static function help(): array
	{
		return [
			self::command.' [-|+]<ECHOAREA> [<DAYS>]',
			'   Use the scan command to resend mail that you havent received yet from an',
			'   echoarea. This is useful if you are rejoining an echoarea, and only want',
			'   to get mail that you dont already have.',
			'   Arguments:',
			'   - ECHOAREA (required) name of area to subscribe or unsubscribe',
			'   - DAYS (optional) number of days to resend mail from this area that you',
			'     If DAYS is omitted, the default is 30.',
		];
	}

	public function process(): string
	{
		Log::debug(sprintf('%s:- Areafix [%s] for [%s] for [%s]',self::LOGKEY,self::command,$this->mo->fftn->ftn,join('|',$this->arguments)));

		$command = self::command.' '.join(' ',$this->arguments);

		if (! ($area=Arr::get($this->arguments,0)))
			return sprintf('%-25s <-- INVALID, AN AREA IS REQUIRED',$command);

		if (! is_numeric($days=Arr::get($this->arguments,1,30)))
			return sprintf('%-25s <-- INVALID, DAYS [%s] NOT NUMERIC',$command,$this->arguments[1]);

		// Area exists
		if ($ea=$this->mo->fftn->domain->echoareas->where('name',$area)->pop()) {
			// If already subscribed
			if ($this->mo->fftn->echoareas->pluck('name')->contains($area)) {
				AreafixRescan::dispatch($this->mo->fftn,$ea,$days)
					->onQueue('mail');

				Log::debug(sprintf('%s:- FTN [%s] SCAN [%s] DAYS [%d]',self::LOGKEY,$this->mo->fftn->ftn,$area,$days));

				return sprintf('%-25s <-- SCAN [%d] DAYS queued',$command,$days);

			// If not subscribed
			} else {
				Log::debug(sprintf('%s:- FTN [%s] is NOT subscribed to [%s], NO ACTION taken',self::LOGKEY,$this->mo->fftn->ftn,$area));

				return sprintf('%-25s <-- NOT subscribed, NO ACTION taken',$command);
			}

		} else {
			Log::debug(sprintf('%s:- FTN [%s] area UNKNOWN [%s], NO ACTION taken',self::LOGKEY,$this->mo->fftn->ftn,$area));

			return sprintf('%-25s <-- AREA UNKNOWN, NO ACTION TAKEN',$command);
		}
	}
}